@@ -37,7 +37,8 @@ from pymongo.server_selectors import readable_server_selector, Selection
 from pymongo.server_type import SERVER_TYPE
 from pymongo.write_concern import WriteConcern
 
-from test import (SkipTest,
+from test import (IntegrationTest,
+                  SkipTest,
                   client_context,
                   unittest,
                   db_user,
@@ -53,7 +54,7 @@ from test.utils import (connected,
 from test.version import Version
 
 
-class TestSelections(unittest.TestCase):
+class TestSelections(IntegrationTest):
 
     @client_context.require_connection
     def test_bool(self):
@@ -486,7 +487,8 @@ class TestMovingAverage(unittest.TestCase):
         avg.add_sample(30)
         self.assertAlmostEqual(15.6, avg.get())
 
-class TestMongosAndReadPreference(unittest.TestCase):
+
+class TestMongosAndReadPreference(IntegrationTest):
 
     def test_read_preference_document(self):
 
